package com.agri.system.service.impl;

import com.agri.system.domain.SysSpecialDtuData;
import com.agri.system.mapper.SysSpecialDtuDataMapper;
import com.agri.system.service.ISysSpecialDtuDataService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 无线传输线管数据Service业务层处理
 * 
 * @author lld
 * @date 2026-01-11
 */
@Service
public class SysSpecialDtuDataServiceImpl extends ServiceImpl<SysSpecialDtuDataMapper, SysSpecialDtuData> implements ISysSpecialDtuDataService
{

    /**
     * 查询无线传输线管数据
     * 
     * @param id 无线传输线管数据主键
     * @return 无线传输线管数据
     */
    @Override
    public SysSpecialDtuData selectSysSpecialDtuDataById(Long id)
    {
        return baseMapper.selectSysSpecialDtuDataById(id);
    }

    /**
     * 查询无线传输线管数据列表
     * 
     * @param sysSpecialDtuData 无线传输线管数据
     * @return 无线传输线管数据
     */
    @Override
    public List<SysSpecialDtuData> selectSysSpecialDtuDataList(SysSpecialDtuData sysSpecialDtuData)
    {
        return baseMapper.selectSysSpecialDtuDataList(sysSpecialDtuData);
    }

    /**
     * 新增无线传输线管数据
     * 
     * @param sysSpecialDtuData 无线传输线管数据
     * @return 结果
     */
    @Override
    public int insertSysSpecialDtuData(SysSpecialDtuData sysSpecialDtuData)
    {
        return baseMapper.insertSysSpecialDtuData(sysSpecialDtuData);
    }

    /**
     * 修改无线传输线管数据
     * 
     * @param sysSpecialDtuData 无线传输线管数据
     * @return 结果
     */
    @Override
    public int updateSysSpecialDtuData(SysSpecialDtuData sysSpecialDtuData)
    {
        return baseMapper.updateSysSpecialDtuData(sysSpecialDtuData);
    }

    /**
     * 批量删除无线传输线管数据
     * 
     * @param ids 需要删除的无线传输线管数据主键
     * @return 结果
     */
    @Override
    public int deleteSysSpecialDtuDataByIds(Long[] ids)
    {
        return baseMapper.deleteSysSpecialDtuDataByIds(ids);
    }

    /**
     * 删除无线传输线管数据信息
     * 
     * @param id 无线传输线管数据主键
     * @return 结果
     */
    @Override
    public int deleteSysSpecialDtuDataById(Long id)
    {
        return baseMapper.deleteSysSpecialDtuDataById(id);
    }
}
